@@ -1,10 +1,11 @@
 class ExampleModel():
     """Example business logic that can be wrapped into a model.
-       The class must contain a 'predict', 'query', or 'run' method."""
+       The class must contain a 'run' method with the input config
+       mapped to the corresponding model parameters."""
     def business_logic(self, revenue: int) -> bool:
         return revenue > 5
 
-    def predict(self, model_input: dict) -> bool:
+    def run(self, model_input: dict) -> bool:
         return self.business_logic(revenue=model_input.get("revenue"))
 
 
@@ -18,8 +19,8 @@ if __name__ == "__main__":
 
     from umlaut import Umlaut
 
-    Umlaut.track_model(
+    Umlaut().track_model(
         model=ExampleModel(),
-        model_name="Quarterly Revenue",
+        model_name="Revenue Forecast",
         run_name="Update",
     )
